pub enum ServerMessage {
Welcome(WelcomePayload),
Tracks(Vec<TrackBinding>),
Sources(Vec<SourceDescriptor>),
PeerInfo(PeerInfoPayload),
PeerJoined(PeerInfoPayload),
PeerLeft(PeerLeftPayload),
Broadcast(ServerBroadcastPayload),
RecordingChange(RecordingStateUpdate),
}Variants
Welcome(WelcomePayload)
Tracks(Vec<TrackBinding>)
Sources(Vec<SourceDescriptor>)
PeerInfo(PeerInfoPayload)
PeerJoined(PeerInfoPayload)
PeerLeft(PeerLeftPayload)
Broadcast(ServerBroadcastPayload)
RecordingChange(RecordingStateUpdate)
Implementations
Sourceimpl ServerMessage
impl ServerMessage
const ENTRIES: &'static [EnvelopeEntry<Self>]
Sourcepub fn into_envelope(self) -> Result<Envelope, Error>
pub fn into_envelope(self) -> Result<Envelope, Error>
encode one server message into the Odoo wire envelope
Errors
returns an error when the typed payload cannot be serialized into the JSON envelope payload
pub(crate) fn decode( tag: &str, payload: Option<Value>, ) -> Result<Self, EnvelopeDecodeError>